@@ -101,18 +101,37 @@ inline double giac_log(double d){
 #include "tinymt32.h"
 #endif
 
+#if defined(HAVE_NO_SYS_TIMES_H) && defined(__MINGW_H)
+#include <time.h>
+#endif
+
 extern "C" int ctrl_c_interrupted(int exception);
+extern "C" void console_print(const char * s);
+extern "C" const char * console_prompt(const char * s);
+
 #if defined HAVE_LIBMICROPYTHON
 #include <string>
 // giac interface to micropython modules
 extern std::string python_console;
 #endif
+#ifdef QUICKJS
+#include <string>
+extern std::string js_vars;
+#endif
+int js_token(const char * list,const char * buf);
+int js_token(const char * buf);
+void update_js_vars();
 
 extern bool freezeturtle;
+extern "C" size_t pythonjs_stack_size,pythonjs_heap_size;
+extern "C" void * bf_ctx_ptr;
+extern "C" size_t bf_global_prec;
 
 #ifndef NO_NAMESPACE_GIAC
 namespace giac {
 #endif // ndef NO_NAMESPACE_GIAC
+  // 3 or 1 if a list of space separated commandnames includes buf
+
   int dichotomic_search(const char * const * tab,unsigned tab_size,const char * s);
   void opaque_double_copy(void * source,void * target);
   double opaque_double_val(const void * source);
@@ -203,7 +222,11 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   void usleep(int );
 #endif
 
+#ifndef HAVE_NO_SYS_TIMES_H
   double delta_tms(struct tms tmp1,struct tms tmp2);
+#elif defined(__MINGW_H)
+  double delta_tms(clock_t tmp1,clock_t tmp2);
+#endif
 
 #define GIAC_DATA_BEGIN   ((char) 2)
 #define GIAC_DATA_END     ((char) 5)
@@ -292,7 +315,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   extern volatile bool ctrl_c,interrupted,kbd_interrupted;
   void ctrl_c_signal_handler(int signum);
 #ifdef TIMEOUT
-#ifndef EMCC
+#if !defined(EMCC) && !defined(EMCC2)
   double time(int );
 #endif
   extern time_t caseval_begin,caseval_current;
